@@ -1,5 +1,3 @@
-#![feature(try_blocks)]
-
 use dll_syringe::{Process, Syringe};
 use std::{
     error::Error,
@@ -11,7 +9,10 @@ use std::{
 mod common;
 
 #[test]
-#[cfg(any(target_arch = "x86", target_arch = "x86_64"))]
+#[cfg(any(
+    target_arch = "x86",
+    all(target_arch = "x86_64", feature = "into_x86_from_x64")
+))]
 fn eject_32() -> Result<(), Box<dyn Error>> {
     eject_test(
         common::build_test_payload_x86()?,
@@ -43,8 +44,8 @@ fn eject_test(
         dummy_process_clone.kill().unwrap();
     });
 
-    let syringe = Syringe::new();
-    let module = syringe.inject(&dummy_process, payload_path.as_ref())?;
+    let mut syringe = Syringe::for_process(&dummy_process);
+    let module = syringe.inject(payload_path)?;
     syringe.eject(module)?;
 
     Ok(())
